#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FUZZY_DEFINITELY_LESS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FUZZY_DEFINITELY_LESS_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/scalar/fuzzy_definitely_less.hpp>

#endif
